@@ -1,12 +1,13 @@
-`plot.fds` <- function (x, plot.type = c("functions", "time", "depth", "density"), labels = NULL, label.cex = 0.7, col = NULL, type = "l", lty = 1, xlab = x$xname, ylab = x$yname, pch = c(1:9,0, letters, LETTERS), ...)
+`plot.fds` <- function (x, plot.type = c("functions", "time", "depth", "density"), labels = NULL, label.cex = 0.7, 
+        col = NULL, type = "l", lty = 1, xlab = x$xname, ylab = x$yname, pch = c(1:9,0, letters, LETTERS), ...)
 {
-    if (class(x)[1] == "fts"|class(x)[1] == "fds"){
+    if (class(x)[1] == "fts"|class(x)[1] == "fds"|class(x)[1] == "sfts"){
         plot.type <- match.arg(plot.type)    
         if (plot.type == "time"){
-            if (class(x)[1] == "fts"){
+            if (class(x)[1] == "fts"|class(x)[1] == "sfts"){
                 if (is.null(col)) {
                     nx <- length(x$x)
-                    palette(rainbow(min(1024,1.25 * nx)))
+                    palette(rainbow(min(1024, 1.25 * nx)))
                     col = 1:nx
                 }
                 if (xlab == x$xname){
@@ -17,7 +18,7 @@
                 }
             }
             else{
-                stop("object is not a functional time series")
+                stop("object is not a functional time series.")
             }            
         }
         else{
@@ -29,20 +30,20 @@
             }
             yy <- as.matrix(x$y)
             if (plot.type == "depth"){
-                sco <- PCAproj(t(yy),k = 2)$score
+                sco <- PCAproj(t(yy), k = 2)$score
                 center <- compute.bagplot(sco)$center
-                index <- order(mahalanobis(sco,center,cov(sco)))
+                index <- order(mahalanobis(sco, center, cov(sco)))
                 yy <- yy[,index]
                 yymax <- yy[,1]
             }   
             else if (plot.type == "density"){
-                     sco <- PCAproj(t(yy),k = 2)$score
-                     X <- cbind(sco[,1],sco[,2])
+                     sco <- PCAproj(t(yy), k = 2)$score
+                     X <- cbind(sco[,1], sco[,2])
                      h = Hscv.diag(X, binned = TRUE)
                      den = kde(x = X, H = h)
                      den = list(x = den$eval.points[[1]], y = den$eval.points[[2]], z = den$estimate)
-                     den2 <- hdrcde:::hdr.info.2d(sco[,1], sco[,2], den, alpha=c(0.01,.5))
-                     index <- order(den2$fxy,decreasing = TRUE)
+                     den2 <- hdrcde:::hdr.info.2d(sco[,1], sco[,2], den, alpha = c(0.01,.5))
+                     index <- order(den2$fxy, decreasing = TRUE)
                      yy <- yy[,index]
                      yymax <- yy[,1]
             }
@@ -52,14 +53,14 @@
             if (plot.type == "functions"){
                 matplot(x$x, yy, col = col, xlab = xlab, ylab = ylab, type = type, lty = lty, pch = pch, ...)
             }
-        else{      
-            matplot(x$x, yy, col = col, xlab = xlab, ylab = ylab, type = type, lty = lty, pch = pch, ...)
-            lines(x$x, yymax, col = "black", ...)
+            else{      
+                matplot(x$x, yy, col = col, xlab = xlab, ylab = ylab, type = type, lty = lty, pch = pch, ...)
+                lines(x$x, yymax, col = "black", ...)
         }
         palette("default") 
         }
    }
    else{
-        stop("object is not a functional time series or a functional data set")
+        stop("object is not a functional model.")
    }
 }
